@@ -1,6 +1,6 @@
 from django.forms import CharField, Form
 
-from dj_cleavejs import CleaveWidget
+from dj_cleavejs import *
 
 
 class TestForm(Form):
@@ -10,3 +10,5 @@ class TestForm(Form):
     windows_95_serial = CharField(
         widget=CleaveWidget(blocks=[3, 7], delimiter="-", numericOnly=True)
     )
+
+    credit_card = CharField(widget=CreditCard())
